pub struct Client {
pub connect_req: ParsedConnectRequest,
pub iface_mac: MacAddr,
pub client_capabilities: ClientCapabilities,
pub connect_timeout: Option<EventHandle>,
/* private fields */
}Expand description
A STA running in Client mode. The Client STA is in its early development process and does not yet manage its internal state machine or track negotiated capabilities.
Fields
connect_req: ParsedConnectRequestiface_mac: MacAddrclient_capabilities: ClientCapabilitiesconnect_timeout: Option<EventHandle>Implementations
Sourceimpl Client
impl Client
pub fn new( connect_req: ParsedConnectRequest, iface_mac: MacAddr, client_capabilities: ClientCapabilities, ) -> Self
pub fn ssid(&self) -> &Ssid
pub fn bssid(&self) -> Bssid
pub fn beacon_period(&self) -> MonotonicDuration
pub fn eapol_required(&self) -> bool
pub fn bind<'a, D>( &'a mut self, ctx: &'a mut Context<D>, scanner: &'a mut Scanner, channel_state: &'a mut ChannelState, ) -> BoundClient<'a, D>