pub struct LocallyInitiated(pub bool);Expand description
LocallyInitiated is true when a disconnect (deauth/disassoc) is initiated from within the device. If the disconnect is initiated remotely (i.e. by the AP if device is a client, or by the client if device is an AP) due to a deauth or disassoc frame, then LocallyInitiated is false.
Tuple Fields
0: boolAuto Trait Implementations
impl Freeze for LocallyInitiated
impl RefUnwindSafe for LocallyInitiated
impl Send for LocallyInitiated
impl Sync for LocallyInitiated
impl Unpin for LocallyInitiated
impl UnsafeUnpin for LocallyInitiated
impl UnwindSafe for LocallyInitiated